pub struct TargetChange {
pub cause: Option<Status>,
pub read_time: Option<DateTime<Utc>>,
pub resume_token: Option<Vec<u8>>,
pub target_change_type: Option<String>,
pub target_ids: Option<Vec<i32>>,
}Expand description
Targets being watched have changed.
This type is not used in any activity, and only used as part of another schema.
Fields
cause: Option<Status>The error that resulted in this change, if applicable.
read_time: Option<DateTime<Utc>>The consistent read_time for the given target_ids (omitted when the target_ids are not at a consistent snapshot). The stream is guaranteed to send a read_time with target_ids empty whenever the entire stream reaches a new consistent snapshot. ADD, CURRENT, and RESET messages are guaranteed to (eventually) result in a new consistent snapshot (while NO_CHANGE and REMOVE messages are not). For a given stream, read_time is guaranteed to be monotonically increasing.
resume_token: Option<Vec<u8>>A token that can be used to resume the stream for the given target_ids, or all targets if target_ids is empty. Not set on every target change.
target_change_type: Option<String>The type of change that occurred.
target_ids: Option<Vec<i32>>The target IDs of targets that have changed. If empty, the change applies to all targets. The order of the target IDs is not defined.